.. AUTO-GENERATED FILE -- DO NOT EDIT!

models.strategy
===============

Module: :mod:`models.strategy`
------------------------------
Inheritance diagram for ``ISLP.models.strategy``:

.. inheritance-diagram:: ISLP.models.strategy 
   :parts: 3

.. automodule:: ISLP.models.strategy

.. currentmodule:: ISLP.models.strategy

Classes
-------

:class:`MinMaxCandidates`
~~~~~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: MinMaxCandidates
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`Stepwise`
~~~~~~~~~~~~~~~~~


.. autoclass:: Stepwise
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`Strategy`
~~~~~~~~~~~~~~~~~


.. autoclass:: Strategy
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

Functions
---------


.. autofunction:: ISLP.models.strategy.first_peak


.. autofunction:: ISLP.models.strategy.fixed_steps


.. autofunction:: ISLP.models.strategy.min_max


.. autofunction:: ISLP.models.strategy.validator_from_constraints

